@@ -39,7 +39,7 @@ for (m in 0:mult) {
         } 
     legend("topleft",legend=paste(colnames(donnee)[col.j],1:length(levels(donnee[,col.j])),sep=" "),text.col=1:length(levels(donnee[,col.j])),cex=0.8,bg="white")
     }
-if (m < mult) get(getOption("device"))()
+if (m < mult) dev.new()
 }
 moyenne <- list()
 moyenne$col.p <- moy
